```console
~ $ vshock
Usage:
  vshock <path> [options]

Where:
  <path> is the location to make input stream of the virtual controller.

Options:
  -h --help       Show this help.
  --port <number> Specify the port number to listen.
  -b --browser    Open the browser automatically.
```
